@@ -201,6 +201,8 @@ class Verifier:
         failure = []
         async with self.get_aiohttp_session() as session:
             for vid, identifier, verified_at, pubkey, metadata_id in candidates:
+                if not isinstance(pubkey, str):
+                    pubkey = pubkey.hex()
                 self.log.info("Checking verification for %s. Last verified %s", identifier, verified_at)
                 uname, domain = identifier.split('@', 1)
                 domain = domain.lower()
